import { Component } from '@angular/core';
import { FormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';

@Component({
  selector: 'app-page-design',
  standalone: true,
  imports: [CommonModule, FormsModule],
  templateUrl: './page-design.html',
  styleUrls: ['./page-design.scss']
})
export class PageDesignComponent {
  activePart: string = 'hood';
  selectedColor: string = '#3498db';
  colors: string[] = [
    '#3498db', '#e74c3c', '#2ecc71', '#f1c40f', 
    '#9b59b6', '#1abc9c', '#e67e22', '#2c3e50', 
    '#ecf0f1', '#e84393'
  ];
  
  partColors: { [key: string]: string } = {
    'hood': '#3498db',
    'body': '#2980b9',
    'sleeve-left': '#3498db',
    'sleeve-right': '#3498db'
  };
  
  aiMessages: any[] = [
    { text: '您好！我是您的羽绒服设计助手。我可以根据您的喜好推荐颜色搭配，或者帮您分析当前设计的流行度。有什么我可以帮您的吗？', isUser: false }
  ];
  aiInput: string = '';

  selectPart(part: string) {
    this.activePart = part;
  }

  selectColor(color: string) {
    this.selectedColor = color;
    this.partColors[this.activePart] = color;
  }

  getPartGradient(part: string): string {
    const color = this.partColors[part];
    const darker = this.darkenColor(color, 20);
    return `linear-gradient(135deg, ${color}, ${darker})`;
  }

  resetDesign() {
    this.partColors = {
      'hood': '#3498db',
      'body': '#2980b9',
      'sleeve-left': '#3498db',
      'sleeve-right': '#3498db'
    };
    this.selectedColor = '#3498db';
    this.activePart = 'hood';
  }

  saveDesign() {
    // 在实际应用中，这里会调用API保存设计
    alert('设计已保存！');
  }

  sendAiMessage() {
    const text = this.aiInput.trim();
    if (!text) return;
    
    this.aiMessages.push({ text, isUser: true });
    this.aiInput = '';
    
    // 模拟AI回复
    setTimeout(() => {
      let response = '';
      if (text.includes('推荐') || text.includes('搭配')) {
        response = '根据您的设计，我推荐尝试海洋蓝与珊瑚橙的搭配，这种组合在近期很受欢迎，能体现活力与时尚感。';
      } else if (text.includes('流行') || text.includes('趋势')) {
        response = '当前最流行的羽绒服颜色搭配是深海蓝黑渐变和日落橙黄渐变。这两种搭配在本月使用率上升了35%。';
      } else {
        response = '我理解您的需求了。作为AI设计助手，我可以为您提供以下帮助：\n1. 推荐颜色搭配方案\n2. 分析当前设计流行度\n3. 提供设计灵感\n4. 生成3D预览效果\n请告诉我您想了解哪方面的内容？';
      }
      
      this.aiMessages.push({ text: response, isUser: false });
    }, 1000);
  }

  private darkenColor(color: string, percent: number): string {
    const num = parseInt(color.replace('#', ''), 16);
    const amt = Math.round(2.55 * percent);
    const R = (num >> 16) - amt;
    const G = (num >> 8 & 0x00FF) - amt;
    const B = (num & 0x0000FF) - amt;
    
    return '#' + (
      0x1000000 +
      (R < 255 ? R < 1 ? 0 : R : 255) * 0x10000 +
      (G < 255 ? G < 1 ? 0 : G : 255) * 0x100 +
      (B < 255 ? B < 1 ? 0 : B : 255)
    ).toString(16).slice(1);
  }
}